@@ -47,20 +47,23 @@ def init_cache_busting(app):
         for filename in filenames:
             # compute version component
             rooted_filename = os.path.join(dirpath, filename)
-            with open(rooted_filename, 'rb') as f:
-                file_hash = hashlib.md5(f.read()).hexdigest()[:7] # nosec
+            try:
+                with open(rooted_filename, 'rb') as f:
+                    file_hash = hashlib.md5(f.read()).hexdigest()[:7]  # nosec
+                # save version to tables
+                file_path = rooted_filename.replace(static_folder, "")
+                file_path = file_path.replace("\\", "/")  # Convert Windows path to web path
+                hash_table[file_path] = file_hash
+            except PermissionError:
+                log.error("No permission to access {} file.".format(rooted_filename))
 
-            # save version to tables
-            file_path = rooted_filename.replace(static_folder, "")
-            file_path = file_path.replace("\\", "/")  # Convert Windows path to web path
-            hash_table[file_path] = file_hash
     log.debug('Finished computing cache-busting values')
 
-    def bust_filename(filename):
-        return hash_table.get(filename, "")
+    def bust_filename(file_name):
+        return hash_table.get(file_name, "")
 
-    def unbust_filename(filename):
-        return filename.split("?", 1)[0]
+    def unbust_filename(file_name):
+        return file_name.split("?", 1)[0]
 
     @app.url_defaults
     # pylint: disable=unused-variable
