@@ -29,12 +29,13 @@ try:
 except ImportError:
     from sqlalchemy.ext.declarative import declarative_base
 
-from . import constants, cli, logger
+from . import constants, logger
 
 
 log = logger.create()
 _Base = declarative_base()
 
+
 class _Flask_Settings(_Base):
     __tablename__ = 'flask_settings'
 
@@ -67,14 +68,14 @@ class _Settings(_Base):
     config_external_port = Column(Integer, default=constants.DEFAULT_PORT)
     config_certfile = Column(String)
     config_keyfile = Column(String)
-    config_trustedhosts = Column(String,default='')
+    config_trustedhosts = Column(String, default='')
     config_calibre_web_title = Column(String, default=u'Calibre-Web')
     config_books_per_page = Column(Integer, default=60)
     config_random_books = Column(Integer, default=4)
     config_authors_max = Column(Integer, default=0)
     config_read_column = Column(Integer, default=0)
     config_title_regex = Column(String, default=r'^(A|The|An|Der|Die|Das|Den|Ein|Eine|Einen|Dem|Des|Einem|Eines)\s+')
-    config_mature_content_tags = Column(String, default='')
+    # config_mature_content_tags = Column(String, default='')
     config_theme = Column(Integer, default=0)
 
     config_log_level = Column(SmallInteger, default=logger.DEFAULT_LOG_LEVEL)
@@ -123,7 +124,7 @@ class _Settings(_Base):
     config_ldap_key_path = Column(String, default="")
     config_ldap_dn = Column(String, default='dc=example,dc=org')
     config_ldap_user_object = Column(String, default='uid=%s')
-    config_ldap_member_user_object = Column(String, default='') #
+    config_ldap_member_user_object = Column(String, default='')
     config_ldap_openldap = Column(Boolean, default=True)
     config_ldap_group_object_filter = Column(String, default='(&(objectclass=posixGroup)(cn=%s))')
     config_ldap_group_members_field = Column(String, default='memberUid')
@@ -134,13 +135,19 @@ class _Settings(_Base):
     config_calibre = Column(String)
     config_rarfile_location = Column(String, default=None)
     config_upload_formats = Column(String, default=','.join(constants.EXTENSIONS_UPLOAD))
-    config_unicode_filename =Column(Boolean, default=False)
+    config_unicode_filename = Column(Boolean, default=False)
 
     config_updatechannel = Column(Integer, default=constants.UPDATE_STABLE)
 
     config_reverse_proxy_login_header_name = Column(String)
     config_allow_reverse_proxy_header_login = Column(Boolean, default=False)
 
+    schedule_start_time = Column(Integer, default=4)
+    schedule_duration = Column(Integer, default=10)
+    schedule_generate_book_covers = Column(Boolean, default=False)
+    schedule_generate_series_covers = Column(Boolean, default=False)
+    schedule_reconnect = Column(Boolean, default=False)
+
     def __repr__(self):
         return self.__class__.__name__
 
@@ -148,12 +155,16 @@ class _Settings(_Base):
 # Class holds all application specific settings in calibre-web
 class _ConfigSQL(object):
     # pylint: disable=no-member
-    def __init__(self, session):
+    def __init__(self):
+        pass
+
+    def init_config(self, session, cli):
         self._session = session
         self._settings = None
         self.db_configured = None
         self.config_calibre_dir = None
         self.load()
+        self.cli = cli
 
         change = False
         if self.config_converterpath == None:  # pylint: disable=access-member-before-definition
@@ -161,7 +172,6 @@ class _ConfigSQL(object):
             self.config_converterpath = autodetect_calibre_binary()
 
         if self.config_kepubifypath == None:  # pylint: disable=access-member-before-definition
-
             change = True
             self.config_kepubifypath = autodetect_kepubify_binary()
 
@@ -171,7 +181,6 @@ class _ConfigSQL(object):
         if change:
             self.save()
 
-
     def _read_from_storage(self):
         if self._settings is None:
             log.debug("_ConfigSQL._read_from_storage")
@@ -179,22 +188,21 @@ class _ConfigSQL(object):
         return self._settings
 
     def get_config_certfile(self):
-        if cli.certfilepath:
-            return cli.certfilepath
-        if cli.certfilepath == "":
+        if self.cli.certfilepath:
+            return self.cli.certfilepath
+        if self.cli.certfilepath == "":
             return None
         return self.config_certfile
 
     def get_config_keyfile(self):
-        if cli.keyfilepath:
-            return cli.keyfilepath
-        if cli.certfilepath == "":
+        if self.cli.keyfilepath:
+            return self.cli.keyfilepath
+        if self.cli.certfilepath == "":
             return None
         return self.config_keyfile
 
-    @staticmethod
-    def get_config_ipaddress():
-        return cli.ip_address or ""
+    def get_config_ipaddress(self):
+        return self.cli.ip_address or ""
 
     def _has_role(self, role_flag):
         return constants.has_flag(self.config_default_role, role_flag)
@@ -249,12 +257,14 @@ class _ConfigSQL(object):
         return logger.get_level_name(self.config_log_level)
 
     def get_mail_settings(self):
-        return {k:v for k, v in self.__dict__.items() if k.startswith('mail_')}
+        return {k: v for k, v in self.__dict__.items() if k.startswith('mail_')}
 
     def get_mail_server_configured(self):
         return bool((self.mail_server != constants.DEFAULT_MAIL_SERVER and self.mail_server_type == 0)
                     or (self.mail_gmail_token != {} and self.mail_server_type == 1))
 
+    def get_scheduled_task_settings(self):
+        return {k: v for k, v in self.__dict__.items() if k.startswith('schedule_')}
 
     def set_from_dictionary(self, dictionary, field, convertor=None, default=None, encode=None):
         """Possibly updates a field of this object.
@@ -286,13 +296,12 @@ class _ConfigSQL(object):
     def toDict(self):
         storage = {}
         for k, v in self.__dict__.items():
-            if k[0] != '_' and not k.endswith("password") and not k.endswith("secret"):
+            if k[0] != '_' and not k.endswith("password") and not k.endswith("secret") and not k == "cli":
                 storage[k] = v
         return storage
 
-
     def load(self):
-        '''Load all configuration values from the underlying storage.'''
+        """Load all configuration values from the underlying storage."""
         s = self._read_from_storage()  # type: _Settings
         for k, v in s.__dict__.items():
             if k[0] != '_':
@@ -325,7 +334,7 @@ class _ConfigSQL(object):
                 self._session.rollback()
 
     def save(self):
-        '''Apply all configuration values to the underlying storage.'''
+        """Apply all configuration values to the underlying storage."""
         s = self._read_from_storage()  # type: _Settings
 
         for k, v in self.__dict__.items():
@@ -360,6 +369,7 @@ class _ConfigSQL(object):
         except AttributeError:
             pass
 
+
 def _migrate_table(session, orm_class):
     changed = False
 
@@ -381,9 +391,9 @@ def _migrate_table(session, orm_class):
                 else:
                     column_type = column.type
                 alter_table = text("ALTER TABLE %s ADD COLUMN `%s` %s %s" % (orm_class.__tablename__,
-                                                                        column_name,
-                                                                        column_type,
-                                                                        column_default))
+                                                                             column_name,
+                                                                             column_type,
+                                                                             column_default))
                 log.debug(alter_table)
                 session.execute(alter_table)
                 changed = True
@@ -411,6 +421,7 @@ def autodetect_calibre_binary():
             return element
     return ""
 
+
 def autodetect_unrar_binary():
     if sys.platform == "win32":
         calibre_path = ["C:\\program files\\WinRar\\unRAR.exe",
@@ -422,6 +433,7 @@ def autodetect_unrar_binary():
             return element
     return ""
 
+
 def autodetect_kepubify_binary():
     if sys.platform == "win32":
         calibre_path = ["C:\\program files\\kepubify\\kepubify-windows-64Bit.exe",
@@ -433,6 +445,7 @@ def autodetect_kepubify_binary():
             return element
     return ""
 
+
 def _migrate_database(session):
     # make sure the table is created, if it does not exist
     _Base.metadata.create_all(session.bind)
@@ -440,14 +453,16 @@ def _migrate_database(session):
     _migrate_table(session, _Flask_Settings)
 
 
-def load_configuration(session):
+def load_configuration(conf, session, cli):
     _migrate_database(session)
 
     if not session.query(_Settings).count():
         session.add(_Settings())
         session.commit()
-    conf = _ConfigSQL(session)
-    return conf
+    # conf = _ConfigSQL()
+    conf.init_config(session, cli)
+    # return conf
+
 
 def get_flask_session_key(_session):
     flask_settings = _session.query(_Flask_Settings).one_or_none()
