@@ -22,6 +22,7 @@ import glob
 import zipfile
 import json
 from io import BytesIO
+from flask_babel.speaklater import LazyString
 
 import os
 
@@ -32,6 +33,13 @@ from .about import collect_stats
 
 log = logger.create()
 
+class lazyEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, LazyString):
+            return str(obj)
+        # Let the base class default method raise the TypeError
+        return json.JSONEncoder.default(self, obj)
+
 def assemble_logfiles(file_name):
     log_list = sorted(glob.glob(file_name + '*'), reverse=True)
     wfd = BytesIO()
@@ -57,8 +65,8 @@ def send_debug():
             file_list.remove(element)
     memory_zip = BytesIO()
     with zipfile.ZipFile(memory_zip, 'w', compression=zipfile.ZIP_DEFLATED) as zf:
-        zf.writestr('settings.txt', json.dumps(config.toDict()))
-        zf.writestr('libs.txt', json.dumps(collect_stats()))
+        zf.writestr('settings.txt', json.dumps(config.toDict(), sort_keys=True, indent=2))
+        zf.writestr('libs.txt', json.dumps(collect_stats(), sort_keys=True, indent=2, cls=lazyEncoder))
         for fp in file_list:
             zf.write(fp, os.path.basename(fp))
     memory_zip.seek(0)
