@@ -33,12 +33,9 @@ try:
 except ImportError:
     from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.exc import OperationalError, InvalidRequestError, IntegrityError
+from sqlalchemy.orm.exc import StaleDataError
 from sqlalchemy.sql.expression import text
 
-#try:
-#    from six import __version__ as six_version
-#except ImportError:
-#    six_version = "not installed"
 try:
     from httplib2 import __version__ as httplib2_version
 except ImportError:
@@ -67,7 +64,7 @@ except ImportError as err:
         importError = err
         gdrive_support = False
 
-from . import logger, cli, config
+from . import logger, cli_param, config
 from .constants import CONFIG_DIR as _CONFIG_DIR
 
 
@@ -141,11 +138,12 @@ class Gdrive:
     def __init__(self):
         self.drive = getDrive(gauth=Gauth.Instance().auth)
 
+
 def is_gdrive_ready():
     return os.path.exists(SETTINGS_YAML) and os.path.exists(CREDENTIALS)
 
 
-engine = create_engine('sqlite:///{0}'.format(cli.gdpath), echo=False)
+engine = create_engine('sqlite:///{0}'.format(cli_param.gd_path), echo=False)
 Base = declarative_base()
 
 # Open session for database connection
@@ -193,11 +191,11 @@ def migrate():
                 session.execute('ALTER TABLE gdrive_ids2 RENAME to gdrive_ids')
             break
 
-if not os.path.exists(cli.gdpath):
+if not os.path.exists(cli_param.gd_path):
     try:
         Base.metadata.create_all(engine)
     except Exception as ex:
-        log.error("Error connect to database: {} - {}".format(cli.gdpath, ex))
+        log.error("Error connect to database: {} - {}".format(cli_param.gd_path, ex))
         raise
 migrate()
 
@@ -321,7 +319,7 @@ def getFolderId(path, drive):
                 session.commit()
         else:
             currentFolderId = storedPathName.gdrive_id
-    except (OperationalError, IntegrityError) as ex:
+    except (OperationalError, IntegrityError, StaleDataError) as ex:
         log.error_or_exception('Database error: {}'.format(ex))
         session.rollback()
     except ApiRequestError as ex:
@@ -547,6 +545,7 @@ def deleteDatabaseOnChange():
     except (OperationalError, InvalidRequestError) as ex:
         session.rollback()
         log.error_or_exception('Database error: {}'.format(ex))
+        session.rollback()
 
 
 def updateGdriveCalibreFromLocal():
@@ -682,8 +681,3 @@ def get_error_text(client_secrets=None):
         return 'Callback url (redirect url) is missing in client_secrets.json'
     if client_secrets:
         client_secrets.update(filedata['web'])
-
-
-def get_versions():
-    return { # 'six': six_version,
-            'httplib2': httplib2_version}
