@@ -29,19 +29,17 @@ from tempfile import gettempdir
 import requests
 import unidecode
 
-from babel.dates import format_datetime
-from babel.units import format_unit
 from flask import send_from_directory, make_response, redirect, abort, url_for
 from flask_babel import gettext as _
+from flask_babel import lazy_gettext as N_
 from flask_login import current_user
-from sqlalchemy.sql.expression import true, false, and_, text, func
+from sqlalchemy.sql.expression import true, false, and_, or_, text, func
 from sqlalchemy.exc import InvalidRequestError, OperationalError
 from werkzeug.datastructures import Headers
 from werkzeug.security import generate_password_hash
 from markupsafe import escape
 from urllib.parse import quote
 
-
 try:
     import advocate
     from advocate.exceptions import UnacceptableAddressException
@@ -51,14 +49,15 @@ except ImportError:
     advocate = requests
     UnacceptableAddressException = MissingSchema = BaseException
 
-from . import calibre_db, cli
+from . import calibre_db, cli_param
 from .tasks.convert import TaskConvert
-from . import logger, config, get_locale, db, ub
+from . import logger, config, db, ub, fs
 from . import gdriveutils as gd
-from .constants import STATIC_DIR as _STATIC_DIR
+from .constants import STATIC_DIR as _STATIC_DIR, CACHE_TYPE_THUMBNAILS, THUMBNAIL_TYPE_COVER, THUMBNAIL_TYPE_SERIES
 from .subproc_wrapper import process_wait
-from .services.worker import WorkerThread, STAT_WAITING, STAT_FAIL, STAT_STARTED, STAT_FINISH_SUCCESS
+from .services.worker import WorkerThread
 from .tasks.mail import TaskEmail
+from .tasks.thumbnail import TaskClearCoverThumbnailCache, TaskGenerateCoverThumbnails
 
 log = logger.create()
 
@@ -73,14 +72,14 @@ except (ImportError, RuntimeError) as e:
 
 
 # Convert existing book entry to new format
-def convert_book_format(book_id, calibrepath, old_book_format, new_book_format, user_id, kindle_mail=None):
+def convert_book_format(book_id, calibre_path, old_book_format, new_book_format, user_id, ereader_mail=None):
     book = calibre_db.get_book(book_id)
     data = calibre_db.get_book_format(book.id, old_book_format)
-    file_path = os.path.join(calibrepath, book.path, data.name)
     if not data:
         error_message = _(u"%(format)s format not found for book id: %(book)d", format=old_book_format, book=book_id)
         log.error("convert_book_format: %s", error_message)
         return error_message
+    file_path = os.path.join(calibre_path, book.path, data.name)
     if config.config_use_google_drive:
         if not gd.getFileFromEbooksFolder(book.path, data.name + "." + old_book_format.lower()):
             error_message = _(u"%(format)s not found on Google Drive: %(fn)s",
@@ -92,9 +91,9 @@ def convert_book_format(book_id, calibrepath, old_book_format, new_book_format,
                               format=old_book_format, fn=data.name + "." + old_book_format.lower())
             return error_message
     # read settings and append converter task to queue
-    if kindle_mail:
+    if ereader_mail:
         settings = config.get_mail_settings()
-        settings['subject'] = _('Send to Kindle')  # pretranslate Subject for e-mail
+        settings['subject'] = _('Send to E-Reader')  # pretranslate Subject for e-mail
         settings['body'] = _(u'This e-mail has been sent via Calibre-Web.')
     else:
         settings = dict()
@@ -105,13 +104,14 @@ def convert_book_format(book_id, calibrepath, old_book_format, new_book_format,
            link)
     settings['old_book_format'] = old_book_format
     settings['new_book_format'] = new_book_format
-    WorkerThread.add(user_id, TaskConvert(file_path, book.id, txt, settings, kindle_mail, user_id))
+    WorkerThread.add(user_id, TaskConvert(file_path, book.id, txt, settings, ereader_mail, user_id))
     return None
 
 
-def send_test_mail(kindle_mail, user_name):
+# Texts are not lazy translated as they are supposed to get send out as is
+def send_test_mail(ereader_mail, user_name):
     WorkerThread.add(user_name, TaskEmail(_(u'Calibre-Web test e-mail'), None, None,
-                     config.get_mail_settings(), kindle_mail, _(u"Test e-mail"),
+                     config.get_mail_settings(), ereader_mail, N_(u"Test e-mail"),
                                           _(u'This e-mail has been sent via Calibre-Web.')))
     return
 
@@ -121,7 +121,7 @@ def send_registration_mail(e_mail, user_name, default_password, resend=False):
     txt = "Hello %s!\r\n" % user_name
     if not resend:
         txt += "Your new account at Calibre-Web has been created. Thanks for joining us!\r\n"
-    txt += "Please log in to your account using the following informations:\r\n"
+    txt += "Please log in to your account using the following information:\r\n"
     txt += "User name: %s\r\n" % user_name
     txt += "Password: %s\r\n" % default_password
     txt += "Don't forget to change your password after first login.\r\n"
@@ -133,54 +133,58 @@ def send_registration_mail(e_mail, user_name, default_password, resend=False):
         attachment=None,
         settings=config.get_mail_settings(),
         recipient=e_mail,
-        taskMessage=_(u"Registration e-mail for user: %(name)s", name=user_name),
+        task_message=N_(u"Registration e-mail for user: %(name)s", name=user_name),
         text=txt
     ))
     return
 
 
-def check_send_to_kindle_with_converter(formats):
-    bookformats = list()
-    if 'EPUB' in formats and 'MOBI' not in formats:
-        bookformats.append({'format': 'Mobi',
-                            'convert': 1,
-                            'text': _('Convert %(orig)s to %(format)s and send to Kindle',
-                                      orig='Epub',
-                                      format='Mobi')})
-    if 'AZW3' in formats and 'MOBI' not in formats:
-        bookformats.append({'format': 'Mobi',
-                            'convert': 2,
-                            'text': _('Convert %(orig)s to %(format)s and send to Kindle',
-                                      orig='Azw3',
-                                      format='Mobi')})
-    return bookformats
+def check_send_to_ereader_with_converter(formats):
+    book_formats = list()
+    if 'MOBI' in formats and 'EPUB' not in formats:
+        book_formats.append({'format': 'Epub',
+                             'convert': 1,
+                             'text': _('Convert %(orig)s to %(format)s and send to E-Reader',
+                                       orig='Mobi',
+                                       format='Epub')})
+    if 'AZW3' in formats and 'EPUB' not in formats:
+        book_formats.append({'format': 'Epub',
+                             'convert': 2,
+                             'text': _('Convert %(orig)s to %(format)s and send to E-Reader',
+                                       orig='Azw3',
+                                       format='Epub')})
+    return book_formats
 
 
-def check_send_to_kindle(entry):
+def check_send_to_ereader(entry):
     """
-        returns all available book formats for sending to Kindle
+        returns all available book formats for sending to E-Reader
     """
     formats = list()
-    bookformats = list()
+    book_formats = list()
     if len(entry.data):
         for ele in iter(entry.data):
             if ele.uncompressed_size < config.mail_size:
                 formats.append(ele.format)
+        if 'EPUB' in formats:
+            book_formats.append({'format': 'Epub',
+                                 'convert': 0,
+                                 'text': _('Send %(format)s to E-Reader', format='Epub')})
         if 'MOBI' in formats:
-            bookformats.append({'format': 'Mobi',
-                                'convert': 0,
-                                'text': _('Send %(format)s to Kindle', format='Mobi')})
+            book_formats.append({'format': 'Mobi',
+                                 'convert': 0,
+                                 'text': _('Send %(format)s to E-Reader', format='Mobi')})
         if 'PDF' in formats:
-            bookformats.append({'format': 'Pdf',
-                                'convert': 0,
-                                'text': _('Send %(format)s to Kindle', format='Pdf')})
+            book_formats.append({'format': 'Pdf',
+                                 'convert': 0,
+                                 'text': _('Send %(format)s to E-Reader', format='Pdf')})
         if 'AZW' in formats:
-            bookformats.append({'format': 'Azw',
-                                'convert': 0,
-                                'text': _('Send %(format)s to Kindle', format='Azw')})
+            book_formats.append({'format': 'Azw',
+                                 'convert': 0,
+                                 'text': _('Send %(format)s to E-Reader', format='Azw')})
         if config.config_converterpath:
-            bookformats.extend(check_send_to_kindle_with_converter(formats))
-        return bookformats
+            book_formats.extend(check_send_to_ereader_with_converter(formats))
+        return book_formats
     else:
         log.error(u'Cannot find book entry %d', entry.id)
         return None
@@ -190,58 +194,46 @@ def check_send_to_kindle(entry):
 # list with supported formats
 def check_read_formats(entry):
     extensions_reader = {'TXT', 'PDF', 'EPUB', 'CBZ', 'CBT', 'CBR', 'DJVU'}
-    bookformats = list()
+    book_formats = list()
     if len(entry.data):
         for ele in iter(entry.data):
             if ele.format.upper() in extensions_reader:
-                bookformats.append(ele.format.lower())
-    return bookformats
+                book_formats.append(ele.format.lower())
+    return book_formats
 
 
 # Files are processed in the following order/priority:
-# 1: If Mobi file is existing, it's directly send to kindle email,
-# 2: If Epub file is existing, it's converted and send to kindle email,
-# 3: If Pdf file is existing, it's directly send to kindle email
-def send_mail(book_id, book_format, convert, kindle_mail, calibrepath, user_id):
+# 1: If Mobi file is existing, it's directly send to E-Reader email,
+# 2: If Epub file is existing, it's converted and send to E-Reader email,
+# 3: If Pdf file is existing, it's directly send to E-Reader email
+def send_mail(book_id, book_format, convert, ereader_mail, calibrepath, user_id):
     """Send email with attachments"""
     book = calibre_db.get_book(book_id)
 
     if convert == 1:
         # returns None if success, otherwise errormessage
-        return convert_book_format(book_id, calibrepath, u'epub', book_format.lower(), user_id, kindle_mail)
+        return convert_book_format(book_id, calibrepath, u'epub', book_format.lower(), user_id, ereader_mail)
     if convert == 2:
         # returns None if success, otherwise errormessage
-        return convert_book_format(book_id, calibrepath, u'azw3', book_format.lower(), user_id, kindle_mail)
+        return convert_book_format(book_id, calibrepath, u'azw3', book_format.lower(), user_id, ereader_mail)
 
     for entry in iter(book.data):
         if entry.format.upper() == book_format.upper():
             converted_file_name = entry.name + '.' + book_format.lower()
             link = '<a href="{}">{}</a>'.format(url_for('web.show_book', book_id=book_id), escape(book.title))
-            email_text = _(u"%(book)s send to Kindle", book=link)
-            WorkerThread.add(user_id, TaskEmail(_(u"Send to Kindle"), book.path, converted_file_name,
-                             config.get_mail_settings(), kindle_mail,
+            email_text = N_(u"%(book)s send to E-Reader", book=link)
+            WorkerThread.add(user_id, TaskEmail(_(u"Send to E-Reader"), book.path, converted_file_name,
+                             config.get_mail_settings(), ereader_mail,
                              email_text, _(u'This e-mail has been sent via Calibre-Web.')))
             return
     return _(u"The requested file could not be read. Maybe wrong permissions?")
 
 
-def shorten_component(s, by_what):
-    l = len(s)
-    if l < by_what:
-        return s
-    l = (l - by_what)//2
-    if l <= 0:
-        return s
-    return s[:l] + s[-l:]
-
-
 def get_valid_filename(value, replace_whitespace=True, chars=128):
     """
     Returns the given string converted to a string that can be used for a clean
     filename. Limits num characters to 128 max.
     """
-
-
     if value[-1:] == u'.':
         value = value[:-1]+u'_'
     value = value.replace("/", "_").replace(":", "_").strip('\0')
@@ -253,8 +245,7 @@ def get_valid_filename(value, replace_whitespace=True, chars=128):
         # pipe has to be replaced with comma
         value = re.sub(r'[|]+', u',', value, flags=re.U)
 
-    filename_encoding_for_length = 'utf-16' if sys.platform == "win32" or sys.platform == "darwin" else 'utf-8'
-    value = value.encode(filename_encoding_for_length)[:chars].decode('utf-8', errors='ignore').strip()
+    value = value.encode('utf-8')[:chars].decode('utf-8', errors='ignore').strip()
 
     if not value:
         raise ValueError("Filename cannot be empty")
@@ -331,12 +322,12 @@ def edit_book_read_status(book_id, read_status=None):
         try:
             calibre_db.update_title_sort(config)
             book = calibre_db.get_filtered_book(book_id)
-            read_status = getattr(book, 'custom_column_' + str(config.config_read_column))
-            if len(read_status):
+            book_read_status = getattr(book, 'custom_column_' + str(config.config_read_column))
+            if len(book_read_status):
                 if read_status is None:
-                    read_status[0].value = not read_status[0].value
+                    book_read_status[0].value = not book_read_status[0].value
                 else:
-                    read_status[0].value = read_status is True
+                    book_read_status[0].value = read_status is True
                 calibre_db.session.commit()
             else:
                 cc_class = db.cc_classes[config.config_read_column]
@@ -345,8 +336,8 @@ def edit_book_read_status(book_id, read_status=None):
                 calibre_db.session.commit()
         except (KeyError, AttributeError, IndexError):
             log.error(
-                "Custom Column No.{} is not existing in calibre database".format(config.config_read_column))
-            return "Custom Column No.{} is not existing in calibre database".format(config.config_read_column)
+                "Custom Column No.{} does not exist in calibre database".format(config.config_read_column))
+            return "Custom Column No.{} does not exist in calibre database".format(config.config_read_column)
         except (OperationalError, InvalidRequestError) as ex:
             calibre_db.session.rollback()
             log.error(u"Read status could not set: {}".format(ex))
@@ -354,9 +345,9 @@ def edit_book_read_status(book_id, read_status=None):
     return ""
 
 
-# Deletes a book fro the local filestorage, returns True if deleting is successfull, otherwise false
+# Deletes a book from the local filestorage, returns True if deleting is successful, otherwise false
 def delete_book_file(book, calibrepath, book_format=None):
-    # check that path is 2 elements deep, check that target path has no subfolders
+    # check that path is 2 elements deep, check that target path has no sub folders
     if book.path.count('/') == 1:
         path = os.path.join(calibrepath, book.path)
         if book_format:
@@ -511,6 +502,7 @@ def upload_new_file_gdrive(book_id, first_author, renamed_author, title, title_d
     return rename_files_on_change(first_author, renamed_author, local_book=book, gdrive=True)
 
 
+
 def update_dir_structure_gdrive(book_id, first_author, renamed_author):
     book = calibre_db.get_book(book_id)
 
@@ -690,6 +682,8 @@ def update_dir_structure(book_id,
 
 
 def delete_book(book, calibrepath, book_format):
+    if not book_format:
+        clear_cover_thumbnail_cache(book.id)        ## here it breaks
     if config.config_use_google_drive:
         return delete_book_gdrive(book, book_format)
     else:
@@ -698,24 +692,38 @@ def delete_book(book, calibrepath, book_format):
 
 def get_cover_on_failure(use_generic_cover):
     if use_generic_cover:
-        return send_from_directory(_STATIC_DIR, "generic_cover.jpg")
-    else:
-        return None
+        try:
+            return send_from_directory(_STATIC_DIR, "generic_cover.jpg")
+        except PermissionError:
+            log.error("No permission to access generic_cover.jpg file.")
+            abort(403)
+    abort(404)
 
 
-def get_book_cover(book_id):
+def get_book_cover(book_id, resolution=None):
     book = calibre_db.get_filtered_book(book_id, allow_show_archived=True)
-    return get_book_cover_internal(book, use_generic_cover_on_failure=True)
+    return get_book_cover_internal(book, use_generic_cover_on_failure=True, resolution=resolution)
 
 
-def get_book_cover_with_uuid(book_uuid,
-                             use_generic_cover_on_failure=True):
+# Called only by kobo sync -> cover not found should be answered with 404 and not with default cover
+def get_book_cover_with_uuid(book_uuid, resolution=None):
     book = calibre_db.get_book_by_uuid(book_uuid)
-    return get_book_cover_internal(book, use_generic_cover_on_failure)
+    return get_book_cover_internal(book, use_generic_cover_on_failure=False, resolution=resolution)
 
 
-def get_book_cover_internal(book, use_generic_cover_on_failure):
+def get_book_cover_internal(book, use_generic_cover_on_failure, resolution=None):
     if book and book.has_cover:
+
+        # Send the book cover thumbnail if it exists in cache
+        if resolution:
+            thumbnail = get_book_cover_thumbnail(book, resolution)
+            if thumbnail:
+                cache = fs.FileSystem()
+                if cache.get_cache_file_exists(thumbnail.filename, CACHE_TYPE_THUMBNAILS):
+                    return send_from_directory(cache.get_cache_file_dir(thumbnail.filename, CACHE_TYPE_THUMBNAILS),
+                                               thumbnail.filename)
+
+        # Send the book cover from Google Drive if configured
         if config.config_use_google_drive:
             try:
                 if not gd.is_gdrive_ready():
@@ -729,6 +737,8 @@ def get_book_cover_internal(book, use_generic_cover_on_failure):
             except Exception as ex:
                 log.error_or_exception(ex)
                 return get_cover_on_failure(use_generic_cover_on_failure)
+
+        # Send the book cover from the Calibre directory
         else:
             cover_file_path = os.path.join(config.config_calibre_dir, book.path)
             if os.path.isfile(os.path.join(cover_file_path, "cover.jpg")):
@@ -739,16 +749,66 @@ def get_book_cover_internal(book, use_generic_cover_on_failure):
         return get_cover_on_failure(use_generic_cover_on_failure)
 
 
+def get_book_cover_thumbnail(book, resolution):
+    if book and book.has_cover:
+        return ub.session \
+            .query(ub.Thumbnail) \
+            .filter(ub.Thumbnail.type == THUMBNAIL_TYPE_COVER) \
+            .filter(ub.Thumbnail.entity_id == book.id) \
+            .filter(ub.Thumbnail.resolution == resolution) \
+            .filter(or_(ub.Thumbnail.expiration.is_(None), ub.Thumbnail.expiration > datetime.utcnow())) \
+            .first()
+
+
+def get_series_thumbnail_on_failure(series_id, resolution):
+    book = calibre_db.session \
+        .query(db.Books) \
+        .join(db.books_series_link) \
+        .join(db.Series) \
+        .filter(db.Series.id == series_id) \
+        .filter(db.Books.has_cover == 1) \
+        .first()
+
+    return get_book_cover_internal(book, use_generic_cover_on_failure=True, resolution=resolution)
+
+
+def get_series_cover_thumbnail(series_id, resolution=None):
+    return get_series_cover_internal(series_id, resolution)
+
+
+def get_series_cover_internal(series_id, resolution=None):
+    # Send the series thumbnail if it exists in cache
+    if resolution:
+        thumbnail = get_series_thumbnail(series_id, resolution)
+        if thumbnail:
+            cache = fs.FileSystem()
+            if cache.get_cache_file_exists(thumbnail.filename, CACHE_TYPE_THUMBNAILS):
+                return send_from_directory(cache.get_cache_file_dir(thumbnail.filename, CACHE_TYPE_THUMBNAILS),
+                                           thumbnail.filename)
+
+    return get_series_thumbnail_on_failure(series_id, resolution)
+
+
+def get_series_thumbnail(series_id, resolution):
+    return ub.session \
+        .query(ub.Thumbnail) \
+        .filter(ub.Thumbnail.type == THUMBNAIL_TYPE_SERIES) \
+        .filter(ub.Thumbnail.entity_id == series_id) \
+        .filter(ub.Thumbnail.resolution == resolution) \
+        .filter(or_(ub.Thumbnail.expiration.is_(None), ub.Thumbnail.expiration > datetime.utcnow())) \
+        .first()
+
+
 # saves book cover from url
 def save_cover_from_url(url, book_path):
     try:
-        if cli.allow_localhost:
+        if cli_param.allow_localhost:
             img = requests.get(url, timeout=(10, 200), allow_redirects=False)  # ToDo: Error Handling
         elif use_advocate:
             img = advocate.get(url, timeout=(10, 200), allow_redirects=False)      # ToDo: Error Handling
         else:
-            log.error("python modul advocate is not installed but is needed")
-            return False, _("Python modul 'advocate' is not installed but is needed for cover downloads")
+            log.error("python module advocate is not installed but is needed")
+            return False, _("Python module 'advocate' is not installed but is needed for cover uploads")
         img.raise_for_status()
         return save_cover(img, book_path)
     except (socket.gaierror,
@@ -799,24 +859,23 @@ def save_cover(img, book_path):
     content_type = img.headers.get('content-type')
 
     if use_IM:
-        if content_type not in ('image/jpeg', 'image/png', 'image/webp', 'image/bmp'):
+        if content_type not in ('image/jpeg', 'image/jpg', 'image/png', 'image/webp', 'image/bmp'):
             log.error("Only jpg/jpeg/png/webp/bmp files are supported as coverfile")
             return False, _("Only jpg/jpeg/png/webp/bmp files are supported as coverfile")
         # convert to jpg because calibre only supports jpg
-        if content_type != 'image/jpg':
-            try:
-                if hasattr(img, 'stream'):
-                    imgc = Image(blob=img.stream)
-                else:
-                    imgc = Image(blob=io.BytesIO(img.content))
-                imgc.format = 'jpeg'
-                imgc.transform_colorspace("rgb")
-                img = imgc
-            except (BlobError, MissingDelegateError):
-                log.error("Invalid cover file content")
-                return False, _("Invalid cover file content")
+        try:
+            if hasattr(img, 'stream'):
+                imgc = Image(blob=img.stream)
+            else:
+                imgc = Image(blob=io.BytesIO(img.content))
+            imgc.format = 'jpeg'
+            imgc.transform_colorspace("rgb")
+            img = imgc
+        except (BlobError, MissingDelegateError):
+            log.error("Invalid cover file content")
+            return False, _("Invalid cover file content")
     else:
-        if content_type not in 'image/jpeg':
+        if content_type not in ['image/jpeg', 'image/jpg']:
             log.error("Only jpg/jpeg files are supported as coverfile")
             return False, _("Only jpg/jpeg files are supported as coverfile")
 
@@ -881,7 +940,7 @@ def check_unrar(unrar_location):
 
     except (OSError, UnicodeDecodeError) as err:
         log.error_or_exception(err)
-        return _('Error excecuting UnRar')
+        return _('Error executing UnRar')
 
 
 def json_serial(obj):
@@ -899,54 +958,6 @@ def json_serial(obj):
     raise TypeError("Type %s not serializable" % type(obj))
 
 
-# helper function for displaying the runtime of tasks
-def format_runtime(runtime):
-    ret_val = ""
-    if runtime.days:
-        ret_val = format_unit(runtime.days, 'duration-day', length="long", locale=get_locale()) + ', '
-    mins, seconds = divmod(runtime.seconds, 60)
-    hours, minutes = divmod(mins, 60)
-    # ToDo: locale.number_symbols._data['timeSeparator'] -> localize time separator ?
-    if hours:
-        ret_val += '{:d}:{:02d}:{:02d}s'.format(hours, minutes, seconds)
-    elif minutes:
-        ret_val += '{:2d}:{:02d}s'.format(minutes, seconds)
-    else:
-        ret_val += '{:2d}s'.format(seconds)
-    return ret_val
-
-
-# helper function to apply localize status information in tasklist entries
-def render_task_status(tasklist):
-    renderedtasklist = list()
-    for __, user, __, task in tasklist:
-        if user == current_user.name or current_user.role_admin():
-            ret = {}
-            if task.start_time:
-                ret['starttime'] = format_datetime(task.start_time, format='short', locale=get_locale())
-                ret['runtime'] = format_runtime(task.runtime)
-
-            # localize the task status
-            if isinstance(task.stat, int):
-                if task.stat == STAT_WAITING:
-                    ret['status'] = _(u'Waiting')
-                elif task.stat == STAT_FAIL:
-                    ret['status'] = _(u'Failed')
-                elif task.stat == STAT_STARTED:
-                    ret['status'] = _(u'Started')
-                elif task.stat == STAT_FINISH_SUCCESS:
-                    ret['status'] = _(u'Finished')
-                else:
-                    ret['status'] = _(u'Unknown Status')
-
-            ret['taskMessage'] = "{}: {}".format(_(task.name), task.message)
-            ret['progress'] = "{} %".format(int(task.progress * 100))
-            ret['user'] = escape(user)  # prevent xss
-            renderedtasklist.append(ret)
-
-    return renderedtasklist
-
-
 def tags_filters():
     negtags_list = current_user.list_denied_tags()
     postags_list = current_user.list_allowed_tags()
@@ -993,3 +1004,28 @@ def get_download_link(book_id, book_format, client):
         return do_download_file(book, book_format, client, data1, headers)
     else:
         abort(404)
+
+
+def clear_cover_thumbnail_cache(book_id):
+    if config.schedule_generate_book_covers:
+        WorkerThread.add(None, TaskClearCoverThumbnailCache(book_id), hidden=True)
+
+
+def replace_cover_thumbnail_cache(book_id):
+    if config.schedule_generate_book_covers:
+        WorkerThread.add(None, TaskClearCoverThumbnailCache(book_id), hidden=True)
+        WorkerThread.add(None, TaskGenerateCoverThumbnails(book_id), hidden=True)
+
+
+def delete_thumbnail_cache():
+    WorkerThread.add(None, TaskClearCoverThumbnailCache(-1))
+
+
+def add_book_to_thumbnail_cache(book_id):
+    if config.schedule_generate_book_covers:
+        WorkerThread.add(None, TaskGenerateCoverThumbnails(book_id), hidden=True)
+
+
+def update_thumbnail_cache():
+    if config.schedule_generate_book_covers:
+        WorkerThread.add(None, TaskGenerateCoverThumbnails())
