@@ -54,7 +54,6 @@ class _Logger(logging.Logger):
             else:
                 self.error(message, *args, **kwargs)
 
-
     def debug_no_auth(self, message, *args, **kwargs):
         message = message.strip("\r\n")
         if message.startswith("send: AUTH"):
@@ -66,6 +65,7 @@ class _Logger(logging.Logger):
 def get(name=None):
     return logging.getLogger(name)
 
+
 def create():
     parent_frame = inspect.stack(0)[1]
     if hasattr(parent_frame, 'frame'):
@@ -75,9 +75,11 @@ def create():
     parent_module = inspect.getmodule(parent_frame)
     return get(parent_module.__name__)
 
+
 def is_debug_enabled():
     return logging.root.level <= logging.DEBUG
 
+
 def is_info_enabled(logger):
     return logging.getLogger(logger).level <= logging.INFO
 
@@ -114,10 +116,10 @@ def get_accesslogfile(log_file):
 
 
 def setup(log_file, log_level=None):
-    '''
+    """
     Configure the logging output.
     May be called multiple times.
-    '''
+    """
     log_level = log_level or DEFAULT_LOG_LEVEL
     logging.setLoggerClass(_Logger)
     logging.getLogger(__package__).setLevel(log_level)
@@ -127,7 +129,7 @@ def setup(log_file, log_level=None):
         # avoid spamming the log with debug messages from libraries
         r.setLevel(log_level)
 
-    # Otherwise name get's destroyed on windows
+    # Otherwise, name gets destroyed on Windows
     if log_file != LOG_TO_STDERR and log_file != LOG_TO_STDOUT:
         log_file = _absolute_log_file(log_file, DEFAULT_LOG_FILE)
 
@@ -159,13 +161,14 @@ def setup(log_file, log_level=None):
         r.removeHandler(h)
         h.close()
     r.addHandler(file_handler)
+    logging.captureWarnings(True)
     return "" if log_file == DEFAULT_LOG_FILE else log_file
 
 
 def create_access_log(log_file, log_name, formatter):
-    '''
+    """
     One-time configuration for the web server's access log.
-    '''
+    """
     log_file = _absolute_log_file(log_file, DEFAULT_ACCESS_LOG)
     logging.debug("access log: %s", log_file)
 
@@ -182,8 +185,7 @@ def create_access_log(log_file, log_name, formatter):
 
     file_handler.setFormatter(formatter)
     access_log.addHandler(file_handler)
-    return access_log, \
-           "" if _absolute_log_file(log_file, DEFAULT_ACCESS_LOG) == DEFAULT_ACCESS_LOG else log_file
+    return access_log, "" if _absolute_log_file(log_file, DEFAULT_ACCESS_LOG) == DEFAULT_ACCESS_LOG else log_file
 
 
 # Enable logging of smtp lib debug output
