@@ -22,17 +22,16 @@ import inspect
 import json
 import os
 import sys
-# from time import time
-
 
 from flask import Blueprint, Response, request, url_for
 from flask_login import current_user
 from flask_login import login_required
+from flask_babel import get_locale
 from sqlalchemy.exc import InvalidRequestError, OperationalError
 from sqlalchemy.orm.attributes import flag_modified
 
 from cps.services.Metadata import Metadata
-from . import constants, get_locale, logger, ub, web_server
+from . import constants, logger, ub, web_server
 
 # current_milli_time = lambda: int(round(time() * 1000))
 
@@ -57,9 +56,10 @@ for f in modules:
         try:
             importlib.import_module("cps.metadata_provider." + a)
             new_list.append(a)
+        except (IndentationError, SyntaxError) as e:
+            log.error("Syntax error for metadata source: {} - {}".format(a, e))
         except ImportError as e:
-            log.error("Import error for metadata source: {} - {}".format(a, e))
-            pass
+            log.debug("Import error for metadata source: {} - {}".format(a, e))
 
 
 def list_classes(provider_list):
@@ -138,6 +138,6 @@ def metadata_search():
                 if active.get(c.__id__, True)
             }
             for future in concurrent.futures.as_completed(meta):
-                data.extend([asdict(x) for x in future.result()])
+                data.extend([asdict(x) for x in future.result() if x])
     # log.info({'Time elapsed {}'.format(current_milli_time()-start)})
     return Response(json.dumps(data), mimetype="application/json")
